@@ -1,6 +1,5 @@
 from __future__ import annotations
-from ctypes import Union
-from typing import Dict, Generic, Iterable, Iterator, List, Set, Optional, Tuple, Type, TypeVar, Callable, overload
+from typing import Dict, Generic, Iterable, Iterator, Union, List, Set, Optional, Tuple, Type, TypeVar, Callable, overload
 
 T = TypeVar("T")
 R = TypeVar("R")
@@ -10,6 +9,12 @@ V = TypeVar("V")
 
 
 class Sequence(Generic[T], Iterable[T]):
+    """
+    Given an [iterator] function constructs a [Sequence] that returns values through the [Iterator]
+    provided by that function.
+    
+    The values are evaluated lazily, and the sequence is potentially infinite.
+    """
     _iter: Iterable[T]
 
     def __init__(self, v: Iterable[T]) -> None:
@@ -1190,7 +1195,6 @@ def it(iterable: Iterable[T]) -> Sequence[T]:
     return sequence(iterable)
 
 
-
 if __name__ == "__main__":
     import doctest
 
